@@ -16,6 +16,7 @@
 
 import logging
 import platform
+import socket
 import sys
 
 from cdpcli import LIST_TYPE
@@ -44,8 +45,11 @@ from cdpcli.extensions.arguments import OverrideRequiredArgsArgument
 from cdpcli.extensions.cliinputjson import add_cli_input_json
 from cdpcli.extensions.configure.configure import ConfigureCommand
 from cdpcli.extensions.generatecliskeleton import add_generate_skeleton
+from cdpcli.extensions.interactivelogin import LoginCommand
+from cdpcli.extensions.logout import LogoutCommand
 from cdpcli.extensions.paginate import add_pagination_params
 from cdpcli.extensions.paginate import check_should_enable_pagination
+from cdpcli.extensions.refdoc import RefdocCommand
 from cdpcli.formatter import get_formatter
 from cdpcli.help import OperationHelpCommand
 from cdpcli.help import ProviderHelpCommand
@@ -56,7 +60,7 @@ from cdpcli.paramfile import ParamFileVisitor
 from cdpcli.parser import ResponseParserFactory
 from cdpcli.retryhandler import create_retry_handler
 from cdpcli.translate import build_retry_config
-
+import urllib3.util.connection as urllib3_connection
 
 LOG = logging.getLogger('cdpcli.clidriver')
 ROOT_LOGGER = logging.getLogger('')
@@ -128,6 +132,9 @@ class CLIDriver(object):
         for service_name in services:
             commands[service_name] = ServiceCommand(self, service_name)
         ConfigureCommand.add_command(commands)
+        LoginCommand.add_command(commands)
+        LogoutCommand.add_command(commands)
+        RefdocCommand.add_command(commands)
         return commands
 
     def _get_argument_table(self):
@@ -203,6 +210,14 @@ class CLIDriver(object):
         else:
             self._setup_logger(logging.WARNING)
 
+        if args.force_ipv4:
+            # Based on SO /a/46972341
+            LOG.debug("Forcing IPv4 connections only")
+
+            def _allowed_gai_family():
+                return socket.AF_INET
+            urllib3_connection.allowed_gai_family = _allowed_gai_family
+
     def _setup_logger(self, log_level):
         ROOT_LOGGER.setLevel(logging.DEBUG)
         ch = logging.StreamHandler()
@@ -232,16 +247,19 @@ class CLIDriver(object):
         if sys.version_info[0] < 3 or \
                 (sys.version_info[0] == 3 and sys.version_info[1] < 6):
             LOG.warn('You are running the CDP CLI under Python %s. The CDP CLI '
-                     'will require Python 3.6 or higher starting in '
-                     'January 2021. '
-                     'Please upgrade now!', sys.version)
+                     'now requires Python 3.6 or higher. Please upgrade now to '
+                     'avoid CLI errors.', sys.version)
 
     def _warn_for_non_public_release(self):
         if RELEASE != 'PUBLIC':
-            LOG.warn('You are running a {0} release of the CDP CLI, which '
+            if RELEASE == 'INTERNAL':
+                article = 'an'
+            else:
+                article = 'a'
+            LOG.warn('You are running {0} {1} release of the CDP CLI, which '
                      'has different capabilities from the standard public '
                      'release. Find the public release at: '
-                     'https://pypi.org/project/cdpcli/'.format(RELEASE))
+                     'https://pypi.org/project/cdpcli/'.format(article, RELEASE))
 
 
 class ServiceCommand(CLICommand):
@@ -432,7 +450,7 @@ class ServiceOperation(object):
             self._operation_model.service_model.service_name,
             parsed_globals.endpoint_url,
             tls_verification,
-            client_creator.context.get_credentials(),
+            client_creator.context.get_credentials(parsed_globals),
             client_config=config)
         return self._invoke_operation_callers(client,
                                               call_parameters,
